#
# pg_profile::database::cis_controls
#
# @summary This class contains the actual code securing the database.
# Here you can customize the security by specifying the CIS rules you *don't* want to apply.
# 
# 
# When these customizations aren't enough, you can replace the class with your own class. See [pg_profile::secured_database](./secured_database.html) for an explanation on how to do this.
#
#
#
# See the file "LICENSE" for the full license governing this code.
#
class pg_profile::database::cis_controls (
  String[1]                   $dbname,
  Optional[String[1]]         $doc_version,
  Optional[String[1]]         $product_version,
  Optional[Array[String[1]]]  $skip_list
) inherits pg_profile::database {
  easy_type::debug_evaluation() # Show local variable on extended debug

  echo { "Making sure database ${dbname} is secured.":
    withpath => false,
  }

  pg_secured::ensure_cis { $dbname:
    product_version => $product_version,
    doc_version     => $doc_version,
    skip_list       => $skip_list,
  }
}
