#
# pg_profile::database::db_init
#
# @summary This class implements the steps to initialize the database for the foirst time.
#
#
#
#
# See the file "LICENSE" for the full license governing this code.
#
class pg_profile::database::db_init (
  Stdlib::Absolutepath
  $data_dir,
  Array[Stdlib::Absolutepath]
  $data_dirs,
  Stdlib::Absolutepath
  $log_dir,
  Array[Stdlib::Absolutepath]
  $log_dirs
) inherits pg_profile {
  echo { 'Ensure Postgres initial setup':
    withpath => false,
  }
  easy_type::debug_evaluation() # Show local variable on extended debug

  if $facts.dig('os','family') == 'RedHat' and $facts.dig('os','selinux','enabled') == true {
    $data_dir_type = 'postgresql_db_t'
    $log_dir_type = 'postgresql_log_t'
  } else {
    $data_dir_type = undef
    $log_dir_type = undef
  }

  #
  # Create all data directories with correct settings
  #
  $data_dirs.each |$dir| {
    unless defined(File[$dir]) {
      file { $dir:
        ensure  => directory,
        owner   => $pg_profile::os_user,
        group   => $pg_profile::os_group,
        seltype => $data_dir_type,
        mode    => '0700',
        before  => Exec['Initialize Postgres Database'],
      }
    }
  }
  #
  # Create all data directories with correct settings
  #
  $log_dirs.each |$dir| {
    unless defined(File[$dir]) {
      file { $dir:
        ensure  => directory,
        owner   => $pg_profile::os_user,
        group   => $pg_profile::os_group,
        seltype => $log_dir_type,
        mode    => '0700',
        before  => Exec['Initialize Postgres Database'],
      }
    }
  }
  exec { 'Initialize Postgres Database':
    command   => "/usr/pgsql-${pg_profile::version}/bin/initdb -D ${data_dir} -X ${log_dir}",
    creates   => "${data_dir}/PG_VERSION",
    user      => $pg_profile::os_user,
    group     => $pg_profile::os_group,
    logoutput => 'on_failure',
  }

  pg_register { 'localhost':
    os_user    => $pg_profile::os_user,
    database   => 'postgres',
    daemonized => false,
    default    => true,
  }
}
