#
# pg_profile::database::db_software
#
# @summary This class contains the definition of the Postgres software packages you want to use on this system.
# When these customizations aren't enough, you can replace the class with your own class. See [pg_profile::database](./database.html) for an explanation on how to do this.
#
#
#
# See the file "LICENSE" for the full license governing this code.
#
class pg_profile::database::db_software (
  String[1]           $base_url,
  Boolean             $install_contrib,
  Boolean             $install_devel,
  Boolean             $install_docs,
  Boolean             $install_llvmjit,
  Boolean             $install_odbc,
  Boolean             $install_plperl,
  Boolean             $install_plpython3,
  Boolean             $install_pltcl,
  Boolean             $install_test,
  Optional[String[1]] $proxy
) inherits pg_profile {
  echo { "Ensure Postgres software version ${pg_profile::version}":
    withpath => false,
  }

  #
  # On RedHat8 disable the standard postgresql module in favor of the
  # vendor supplied one that we add later.
  #
  if $::facts['os']['family'] == 'RedHat' and $::facts['os']['release']['major'] == '8' {
    package { 'postgresql':
      ensure   => 'disabled',
      provider => 'dnfmodule',
    }
  }

  $package_version = split($pg_profile::version, '[.]')[0]
  $gpg_key_path    = "/etc/pki/rpm-gpg/RPM-GPG-KEY-PGDG-${package_version}"

  easy_type::debug_evaluation() # Show local variable on extended debug

  file { $gpg_key_path:
    source => 'puppet:///modules/pg_profile/postgres-repo.key',
    owner  => 'root',
    group  => 'root',
    mode   => '0644',
  }

  -> yumrepo { 'yum.postgresql.org':
    descr    => "PostgreSQL ${pg_profile::version} \$releasever - \$basearch",
    baseurl  => $base_url,
    enabled  => 1,
    gpgcheck => 1,
    gpgkey   => "file:///etc/pki/rpm-gpg/RPM-GPG-KEY-PGDG-${package_version}",
    proxy    => $proxy,
  }

  -> package { "postgresql${package_version}-server":
    ensure   => 'present',
    provider => 'yum',
  }

  $additional_packages = ['contrib','devel','docs','llvmjit','odbc','plperl','plpython3','pltcl','test'].each | $package| {
    # lint:ignore:no_erb_template
    $value = inline_template("<%= @install_${package} %>")
    # lint:endignore:no_erb_template
    if $value == 'true' {
      echo { "Ensure optional Postgres version ${pg_profile::version} package ${package} ":
        withpath => false,
      }

      package { "postgresql${package_version}-${package}":
        ensure  => 'present',
        # require => Package["postgresql${package_version}-server"],
      }
    }
  }
}
